@@ -16,9 +16,7 @@ class FireworksProviderDataValidator(BaseModel):
 async def get_adapter_impl(config: FireworksImplConfig, _deps):
     from .fireworks import FireworksInferenceAdapter
 
-    assert isinstance(
-        config, FireworksImplConfig
-    ), f"Unexpected config type: {type(config)}"
+    assert isinstance(config, FireworksImplConfig), f"Unexpected config type: {type(config)}"
     impl = FireworksInferenceAdapter(config)
     await impl.initialize()
     return impl
